@@ -6,6 +6,7 @@ use Plack::Util;
 use HTTP::Date;
 use Plack::MIME;
 use DirHandle;
+use URI::Escape;
 
 # Stolen from rack/directory.rb
 my $dir_file = "<tr><td class='name'><a href='%s'>%s</a></td><td class='size'>%s</td><td class='type'>%s</td><td class='mtime'>%s</td></tr>";
@@ -70,6 +71,8 @@ sub serve_path {
             $url      .= "/";
         }
 
+        $url = join '/', map {uri_escape($_)} split m{/}, $url;
+
         my $mime_type = $is_dir ? 'directory' : ( Plack::MIME->mime_type($file) || 'text/plain' );
         push @files, [ $url, $basename, $stat[7], $mime_type, HTTP::Date::time2str($stat[9]) ];
     }
